==> owncloud-tasks_0.7.1.orig.tar.gz: tasks-0.7.1/l10n/id.php <==
<?php
$TRANSLATIONS = array(
"Tasks" => "Tugas",
"Due yesterday" => "Jatuh tempo kemarin",
"Due today" => "Jatuh tempo hari ini",
"Due tomorrow" => "Jatuh tempo besok",
"Due on" => "Jatuh tempo pada",
"Started yesterday" => "Dimulai kemarin",
"Starts today" => "Dimulai hari ini",
"Starts tomorrow" => "Dimulai besok",
"Started on" => "Dimulai pada",
"Starts on" => "Dimulai pada",
"[Remind me yesterday at ]HH:mm" => "[Ingatkan saya kemarin pada ]HH:mm",
"[Remind me today at ]HH:mm" => "[Ingatkan saya hari ini ]HH:mm",
"[Remind me tomorrow at ]HH:mm" => "[Ingatkan saya besok pada ]HH:mm",
"[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" => "[Ingatkan saya pada ]MMM DD, YYYY,[ at ]HH:mm",
"Yesterday" => "Kemarin",
"Today" => "Hari Ini",
"Tomorrow" => "Besok",
"in %s" => "dalam %s",
"%s ago" => "%s yang lalu",
"seconds" => "detik",
"a minute" => "semenit",
"%d minutes" => "%d menit",
"an hour" => "sejam",
"%d hours" => "%d jam",
"a day" => "sehari",
"%d days" => "%d hari",
"a month" => "sebulan",
"%d months" => "%d bulan",
"a year" => "setahun",
"%d years" => "%d tahun",
"Hours" => "Jam",
"Minutes" => "Menit",
"week" => "minggu",
"weeks" => "minggu",
"day" => "hari",
"days" => "hari",
"hour" => "jam",
"hours" => "jam",
"minute" => "menit",
"minutes" => "menit",
"second" => "detik",
"before beginning" => "sebelum diawal",
"after beginning" => "setelah diawal",
"before end" => "sebelum diakhir",
"after end" => "setelah diakhir",
"Comment" => "Komentar",
"Add a comment" => "Tambah komentar",
"This will delete the Calendar \"%s\" and all of its entries." => "Hal ini akan menghapus Kalender \"%s\" dan semua isinya",
"The name \"%s\" is already used." => "Nama \"%s\" sudah digunakan.",
"An empty name is not allowed." => "Nama kosong tidak diperbolehkan.",
"Hidden" => "Sembunyi",
"Visible" => "Tampak",
"Automatic" => "Otomatis",
"Sunday" => "Minggu",
"Monday" => "Senin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Kamis",
"Friday" => "Jumat",
"Saturday" => "Sabtu",
"Add an important item in \"%s\"..." => "Tambah item penting dalam \"%s\"...",
"Add an item due today in \"%s\"..." => "Tambah item jatuh tempo hari ini dalam \"%s\"...",
"Add an item in \"%s\"..." => "Tambah item dalam \"%s\"...",
"Add a current item in \"%s\"..." => "Tambah item terbaru dalam \"%s\"...",
"_%n Completed Task_::_%n Completed Tasks_" => array("%n Tugas Diselesaikan"),
"Set due date" => "Atur tanggal jatuh tempo",
"%s %% completed" => "%s %% selesai",
"priority %s: " => "prioritas %s:",
"high" => "tinggi",
"medium" => "sedang",
"low" => "rendah",
"no priority assigned" => "tidak ada prioritas yang ditetapkan",
"Remind me" => "Ingatkan saya",
"at the end" => "di akhir",
"at the beginning" => "di awal",
"Set start date" => "Atur tanggal mulai",
"Important" => "Penting",
"Week" => "Minggu",
"All" => "Semua",
"Current" => "Saat ini",
"Completed" => "Selesai",
"rename" => "ubah nama",
"delete" => "hapus",
"Add List..." => "Tambah Daftar...",
"New List" => "Daftar Baru",
"Settings" => "Pengaturan",
"Start of week" => "Mulai minggu",
"Visibility of Smart Collections" => "Visibilitas Koleksi Cerdas",
"Load remaining completed tasks." => "Memuat sisa tugas yang harus diselesaikan.",
"(New category)" => "(Kategori baru)",
"Select categories..." => "Pilih kategori...",
"Loading the task..." => "Memuat tugas...",
"Task not found!" => "Tugas tidak ditemukan!"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-tasks_0.8.1.orig.tar.gz: tasks-0.8.1/l10n/id.php <==
<?php
$TRANSLATIONS = array(
"Tasks" => "Tugas",
"Tasks app is unavailable because the calendar is not installed" => "Aplikasi tugas tidak tersedia karena kalender belum terpasang",
"Due yesterday" => "Jatuh tempo kemarin",
"Due today" => "Jatuh tempo hari ini",
"Due tomorrow" => "Jatuh tempo besok",
"Due on" => "Jatuh tempo pada",
"Started yesterday" => "Dimulai kemarin",
"Starts today" => "Dimulai hari ini",
"Starts tomorrow" => "Dimulai besok",
"Started on" => "Dimulai pada",
"Starts on" => "Dimulai pada",
"[Remind me yesterday at ]HH:mm" => "[Ingatkan saya kemarin pada ]HH:mm",
"[Remind me today at ]HH:mm" => "[Ingatkan saya hari ini ]HH:mm",
"[Remind me tomorrow at ]HH:mm" => "[Ingatkan saya besok pada ]HH:mm",
"[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" => "[Ingatkan saya pada ]MMM DD, YYYY,[ at ]HH:mm",
"Yesterday" => "Kemarin",
"Today" => "Hari Ini",
"Tomorrow" => "Besok",
"in %s" => "dalam %s",
"%s ago" => "%s yang lalu",
"seconds" => "detik",
"a minute" => "semenit",
"%d minutes" => "%d menit",
"an hour" => "sejam",
"%d hours" => "%d jam",
"a day" => "sehari",
"%d days" => "%d hari",
"a month" => "sebulan",
"%d months" => "%d bulan",
"a year" => "setahun",
"%d years" => "%d tahun",
"Hours" => "Jam",
"Minutes" => "Menit",
"week" => "minggu",
"weeks" => "minggu",
"day" => "hari",
"days" => "hari",
"hour" => "jam",
"hours" => "jam",
"minute" => "menit",
"minutes" => "menit",
"second" => "detik",
"before beginning" => "sebelum diawal",
"after beginning" => "setelah diawal",
"before end" => "sebelum diakhir",
"after end" => "setelah diakhir",
"Comment" => "Komentar",
"Add a comment" => "Tambah komentar",
"This will delete the Calendar \"%s\" and all of its entries." => "Hal ini akan menghapus Kalender \"%s\" dan semua isinya",
"The name \"%s\" is already used." => "Nama \"%s\" sudah digunakan.",
"An empty name is not allowed." => "Nama kosong tidak diperbolehkan.",
"Hidden" => "Sembunyi",
"Visible" => "Tampak",
"Automatic" => "Otomatis",
"Sunday" => "Minggu",
"Monday" => "Senin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Kamis",
"Friday" => "Jumat",
"Saturday" => "Sabtu",
"Add an important item in \"%s\"..." => "Tambah item penting dalam \"%s\"...",
"Add an item due today in \"%s\"..." => "Tambah item jatuh tempo hari ini dalam \"%s\"...",
"Add an item in \"%s\"..." => "Tambah item dalam \"%s\"...",
"Add a current item in \"%s\"..." => "Tambah item terbaru dalam \"%s\"...",
"Add a subtask to \"%s\"..." => "Tambah sub tugas ke \"%s\"...",
"_%n Completed Task_::_%n Completed Tasks_" => array("%n Tugas Diselesaikan"),
"Set due date" => "Atur tanggal jatuh tempo",
"%s %% completed" => "%s %% selesai",
"priority %s: " => "prioritas %s:",
"high" => "tinggi",
"medium" => "sedang",
"low" => "rendah",
"no priority assigned" => "tidak ada prioritas yang ditetapkan",
"Remind me" => "Ingatkan saya",
"at the end" => "di akhir",
"at the beginning" => "di awal",
"Set start date" => "Atur tanggal mulai",
"Important" => "Penting",
"Week" => "Minggu",
"All" => "Semua",
"Current" => "Saat ini",
"Completed" => "Selesai",
"rename" => "ubah nama",
"delete" => "hapus",
"Add List..." => "Tambah Daftar...",
"New List" => "Daftar Baru",
"Settings" => "Pengaturan",
"Start of week" => "Mulai minggu",
"Visibility of Smart Collections" => "Visibilitas Koleksi Cerdas",
"Load remaining completed tasks." => "Memuat sisa tugas yang harus diselesaikan.",
"(New category)" => "(Kategori baru)",
"Select categories..." => "Pilih kategori...",
"Loading the task..." => "Memuat tugas...",
"Task not found!" => "Tugas tidak ditemukan!",
"add a subtask to" => "tambah sub tugas ke"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
